Get the state space dimensions for a particular model configuration

get_leapfrog_ss(configuration)

Arguments

configuration

The configuration to get state space for, see list_model_configurations.

Value

State space as a named list