Prepare inputs from Spectrum PJNZ

process_pjnz(
  pjnz,
  use_coarse_age_groups = FALSE,
  extract_child_params = FALSE,
  bypass_adult = FALSE
)

Arguments

pjnz

path to PJNZ file

use_coarse_age_groups

use the coarse age stratification

extract_child_params

If TRUE, then child parameters required to run the child model will be extracted. If FALSE, only adult parameters will be extracted from the PJNZ.

bypass_adult

produce parameters that will bypass the adult model when running the child model variant

Value

list of input parameters

Examples

pjnz <- system.file(
  "pjnz/bwa_aim-adult-art-no-special-elig_v6.13_2022-04-18.PJNZ",
  package = "leapfrog")
parameters <- process_pjnz(pjnz)
#>  Some tags were not found in file:
#>  Tag not found in DP for `adult_non_aids_excess_mort`, returning `NULL`
#>  Tag not found in DP for `incidence_input`, returning `NULL`
#>  Tag not found in DP for `adult_art_adj_factor`, returning `NULL`
#>  Tag not found in DP for `adult_art_adj_factor_flag`, returning `NULL`
#>  Tag not found in DP for `adult_pats_alloc_to_from_other_region`, returning
#>   `NULL`
#>  Tag not found in DP for `nosocomial_infections`, returning `NULL`
#> This message is displayed once per session.