R/RcppExports.R
get_leapfrog_ss.Rd
Get the state space dimensions for a particular model configuration
get_leapfrog_ss(configuration)
The configuration to get state space for, see list_model_configurations.
State space as a named list